<?php

global $authenticate_text;
$authenticate_text = array (

'loginsuccessful'  =>  'Login erfolgreich.',
'loginfailed'      =>  'Login fehlgeschlagen!',
'userandpass'      =>  'Benutzername und/oder Passwort fehlt.',
'youareloggedout'  =>  'Sie wurden ausgeloggt.',
'waitwhiletransfer'=>  'Sie werden weitergeleitet...',
'clicknowait'      =>  'Weiter',

// Added in 0.9.7
'accountdisabled'  =>  'Ihr Benutzerkonto wurde deaktiviert. Wenden Sie sich an den Flyspray-Administrator.',

);
?>
